@@ -9,7 +9,7 @@ use Crypt::Eksblowfish::Bcrypt ();
 use 5.008001;
 use utf8;
 
-our $VERSION = '1.204';
+our $VERSION = '1.205';
 $VERSION = eval $VERSION;
 
 sub add {
@@ -29,8 +29,7 @@ sub clone {
         cost    => $self->cost,
         salt    => $self->salt,
         _buffer => $self->{_buffer},
-        },
-        ref($self);
+    }, ref($self);
 }
 
 sub cost {
